@@ -4,6 +4,17 @@ context("test-split.R")
 
 ################################################################################
 
+test_that("'split_every_nlines()' works", {
+
+  tmp <- bigreadr::fwrite2(iris)
+  test <- bigreadr:::split_every_nlines(tmp, tmp, 20, TRUE)
+  files <- list.files(tempdir(), basename(tmp), full.names = TRUE)
+  files2 <- c(tmp, paste0(tmp, "_", 1:8, ".txt"))
+  expect_identical(normalizePath(sort(files)), normalizePath(files2))
+})
+
+################################################################################
+
 test_that("'split_file()' works", {
 
   strings <- c("", "", " ", sapply(10^(seq(0, 4, by = 0.2)), function(i) {
